# Licensed under a 3-clause BSD style license - see LICENSE.rst

import os
from os.path import join

from distutils.core import Extension


BLS_ROOT = os.path.relpath(os.path.dirname(__file__))


def get_extensions():
    ext = Extension(
        "astropy.stats.bls._impl",
        sources=[
            join(BLS_ROOT, "bls.c"),
            join(BLS_ROOT, "_impl.pyx"),
        ],
        include_dirs=["numpy"],
    )
    return [ext]



# Autogenerated by Astropy's setup.py on 2018-12-31 23:55:33 UTC
from __future__ import unicode_literals
import datetime

version = "3.1.1"
githash = "63355d3d334b7d8c05cd517a8edfaca07ccfb65b"


major = 3
minor = 1
bugfix = 1

version_info = (major, minor, bugfix)

release = True
timestamp = datetime.datetime(2018, 12, 31, 23, 55, 33)
debug = False

astropy_helpers_version = "3.1"

try:
    from ._compiler import compiler
except ImportError:
    compiler = "unknown"

try:
    from .cython_version import cython_version
except ImportError:
    cython_version = "unknown"
